@@ -16,7 +16,6 @@ from typing import Optional, Tuple, Set, Type, Any, Union
 
 logger = logging.getLogger('ezmsg')
 
-
 class GraphContext:
 
     _address: Address
@@ -25,6 +24,7 @@ class GraphContext:
 
     _shm_server: Optional[SHMServer]
     _graph_server: Optional[GraphServer]
+    _connection: GraphServer.Connection
 
     def __init__(self, address: AddressType = GRAPHSERVER_ADDR) -> None:
         self._address = Address(*address)
@@ -44,25 +44,26 @@ class GraphContext:
         return sub
 
     async def connect(self, from_topic: str, to_topic: str) -> None:
-        await GraphServer.connect(from_topic, to_topic, self._address)
+        await self._connection.connect(from_topic, to_topic)
         self._edges.add((from_topic, to_topic))
 
     async def disconnect(self, from_topic: str, to_topic: str) -> None:
-        await GraphServer.disconnect(from_topic, to_topic, self._address)
+        await self._connection.disconnect(from_topic, to_topic)
         self._edges.discard((from_topic, to_topic))
 
-    async def pause(self) -> None:
-        await GraphServer.pause(self._address)
-
     async def sync(self, timeout: Optional[float] = None) -> None:
-        await GraphServer.sync(timeout, self._address)
+        await self._connection.sync(timeout)
+
+    async def pause(self) -> None:
+        await self._connection.pause()
 
     async def resume(self) -> None:
-        await GraphServer.resume(self._address)
+        await self._connection.resume()
 
     async def __aenter__(self):
         self._shm_server = await SHMServer.ensure_running()
         self._graph_server = await GraphServer.ensure_running(self._address)
+        self._connection = GraphServer.Connection(self._address)
         return self
 
     async def __aexit__(self,
@@ -70,6 +71,10 @@ class GraphContext:
                         exc_v: Optional[Any],
                         exc_tb: Optional[TracebackType]
                         ) -> bool:
+        await self._exit_context()
+        return False
+
+    async def _exit_context(self) -> None:
         for client in self._clients:
             client.close()
 
@@ -79,18 +84,15 @@ class GraphContext:
 
         for edge in self._edges:
             try:
-                await GraphServer.disconnect(*edge, address=self._address)
-            except (ConnectionRefusedError, BrokenPipeError) as e:
-                logger.warn(f'Could not remove edge from GraphServer: {e}')
+                await self._connection.disconnect(*edge)
+            except (ConnectionRefusedError, BrokenPipeError, ConnectionResetError) as e:
+                logger.warn(f'Could not remove edge {edge} from GraphServer: {e}')
 
         if self._graph_server is not None:
-            logger.debug( 'Terminating GraphServer' )
-            self._graph_server.shutdown()
-            self._graph_server.join()
+            logger.info( 'Terminating GraphServer' )
+            self._graph_server.stop()
 
         if self._shm_server is not None:
-            logger.debug( 'Terminating SHMServer' )
-            self._shm_server.shutdown()
-            self._shm_server.join()
-
-        return False
+            logger.info( 'Terminating SHMServer' )
+            self._shm_server.stop()
+    
